# EMLvp change log
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## (1.1.0) 2024-02-17
### Changed/Fixed
- Catch ValueError in `process_one_document`
- Add unicode inspections to EML documents

## (1.0.0) 2024-02-17
### Changed/Fixed
- Add option to normalize whitespace in EML XML documents
- Release version 1.0.0 - woohoo!

## (0.0.6) 2023-07-21
### Changed/Fixed
- Force opening all files as UTF-8 to support Windows
- Fix scope of summary statistics output

## (0.0.5) 2023-02-06
### Changed/Fixed
- Apply "black" formatting and "pylint" refactors

## (0.0.4) 2023-02-02
### Changed/Fixed
- Add version option to emlvp CLI application

## (0.0.3) 2023-02-02
### Changed/Fixed
- Update documentation

## (0.0.2) 2023-02-01
### Changed/Fixed
- Add explicit dependencies to setup.py

## (0.0.1) 2023-01-31
### Changed/Fixed
- First release